@@ -856,6 +856,35 @@ class URITypeTests(TypeTestHelper, unittest.TestCase):
         self.assertConvertedValue('http://www.example.com',
                                   'http://www.example.com')
 
+    def test_equality(self):
+        a = types.URI()
+        b = types.URI()
+        self.assertEqual(a, b)
+
+    def test_equality_length(self):
+        a = types.URI(max_length=5)
+        b = types.URI(max_length=5)
+        self.assertEqual(a, b)
+
+    def test_equality_length_not(self):
+        a = types.URI()
+        b = types.URI(max_length=5)
+        c = types.URI(max_length=10)
+        self.assertNotEqual(a, b)
+        self.assertNotEqual(c, b)
+
+    def test_equality_schemes(self):
+        a = types.URI(schemes=['ftp'])
+        b = types.URI(schemes=['ftp'])
+        self.assertEqual(a, b)
+
+    def test_equality_schemes_not(self):
+        a = types.URI()
+        b = types.URI(schemes=['ftp'])
+        c = types.URI(schemes=['http'])
+        self.assertNotEqual(a, b)
+        self.assertNotEqual(c, b)
+
 
 class PortTypeTests(TypeTestHelper, unittest.TestCase):
     type = types.Port()
@@ -1010,3 +1039,40 @@ class PortTypeTests(TypeTestHelper, unittest.TestCase):
         t = types.Port(max=0)
         self.assertRaises(ValueError, t, 1)
         t(0)
+
+
+class FormatSampleDefaultTests(unittest.TestCase):
+    def test_string(self):
+        t = types.String()
+        self.assertEqual([' bar '],
+                         t.format_defaults('foo', sample_default=' bar '))
+
+    def test_string_non_str(self):
+        t = types.String()
+        e = Exception('bar')
+        self.assertEqual(['bar'],
+                         t.format_defaults('', sample_default=e))
+
+    def test_string_non_str_spaces(self):
+        t = types.String()
+        e = Exception(' bar ')
+        self.assertEqual(['" bar "'],
+                         t.format_defaults('', sample_default=e))
+
+    def test_list_string(self):
+        t = types.List(item_type=types.String())
+        test_list = ['foo', Exception(' bar ')]
+        self.assertEqual(['foo," bar "'],
+                         t.format_defaults('', sample_default=test_list))
+
+    def test_list_no_type(self):
+        t = types.List()
+        test_list = ['foo', Exception(' bar ')]
+        self.assertEqual(['foo," bar "'],
+                         t.format_defaults('', sample_default=test_list))
+
+    def test_list_not_list(self):
+        t = types.List()
+        self.assertEqual(['foo'],
+                         t.format_defaults('',
+                                           sample_default=Exception('foo')))
